==> IEDB_NG_PHBR-0.1-beta.tar.gz: ng_phbr-0.1-beta/src/PhbrArgumentParser.py <==
import textwrap
import argparse
import validators
import os
import sys
from NGArgumentParser import NGArgumentParser


class PhbrArgumentParser(NGArgumentParser):
    def __init__(self):
        super().__init__()

        # ADD program details by setting params, such as
        # prog, usage, description, epilog, etc.
        # -----------------------------------------------------
        self.description = textwrap.dedent(
            '''
            Compute PHBR score for each peptide.
            '''
        )

        # ADD subparser prediction descriptions
        # -----------------------------------------------------
        pred_parser = self.add_predict_subparser(
            help='Compute PHBR score for each peptide.',
            description='Compute PHBR score for each peptide.'
        )

        # ADD tool-specific params 
        # -----------------------------------------------------
        # pred_parser.add_argument("--input-tsv", "-t",
        #                         dest="input_tsv",
        #                         type=argparse.FileType('r'),
        #                         default=None,
        #                         help="Perform counting given a TSV file.",
        #                         )
        pred_parser.add_argument("--input-json", "-j",
                                dest="input_json",
                                type=argparse.FileType('r'),
                                default=None,
                                help="Perform counting given a JSON file.",
                                )
        pred_parser.add_argument("--output-prefix", "-o",
                                dest="output_prefix",
                                help="prediction result output prefix.",
                                metavar="OUTPUT_PREFIX")
        pred_parser.add_argument("--output-format", "-f",
                                dest="output_format",
                                default="tsv",
                                help="prediction result output format (Default=tsv)",
                                metavar="OUTPUT_FORMAT")

==> IEDB_NG_PHBR-0.2-beta.tar.gz: ng_phbr-0.2-beta/src/PhbrArgumentParser.py <==
import textwrap
import argparse
import validators
import os
import sys
from NGArgumentParser import NGArgumentParser


class PhbrArgumentParser(NGArgumentParser):
    def __init__(self):
        super().__init__()

        # ADD program details by setting params, such as
        # prog, usage, description, epilog, etc.
        # -----------------------------------------------------
        self.description = textwrap.dedent(
            '''
            Compute PHBR score for each peptide.
            '''
        )

        # ADD subparser prediction descriptions
        # -----------------------------------------------------
        pred_parser = self.add_predict_subparser(
            help='Compute PHBR score for each peptide.',
            description='Compute PHBR score for each peptide.'
        )

        # ADD tool-specific params 
        # -----------------------------------------------------
        # pred_parser.add_argument("--input-tsv", "-t",
        #                         dest="input_tsv",
        #                         type=argparse.FileType('r'),
        #                         default=None,
        #                         help="Perform counting given a TSV file.",
        #                         )
        pred_parser.add_argument("--input-json", "-j",
                                dest="input_json",
                                type=argparse.FileType('r'),
                                default=None,
                                help="Perform counting given a JSON file.",
                                )
        pred_parser.add_argument("--output-prefix", "-o",
                                dest="output_prefix",
                                help="prediction result output prefix.",
                                metavar="OUTPUT_PREFIX")
        pred_parser.add_argument("--output-format", "-f",
                                dest="output_format",
                                default="tsv",
                                help="prediction result output format (Default=tsv)",
                                metavar="OUTPUT_FORMAT")
        pred_parser.add_argument("--output-dir", "-d",
                        dest="output_dir",
                        default="/tmp",
                        help="prediction result output directory (Default=/tmp)",
                        metavar="OUTPUT_DIR")
